@@ -35,6 +35,8 @@
 
 #ifdef _MSC_VER
 #include "msinttypes.h"
+#elif defined(__sun) || defined(__sun__)
+#include <sys/inttypes.h>
 #else
 #include <stdint.h>
 #endif
@@ -42,7 +44,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "sha256.h"
+#include "sha256.c.inc"
 #include "sysendian.h"
 
 #include "crypto_scrypt.h"
